==> gravestones-1.2.4%2B1.21.1%2BA-sources.jar: net/pneumono/gravestones/block/TechnicalGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import com.mojang.serialization.MapCodec;
import net.minecraft.block.*;
import net.minecraft.class_1264;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1927;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2398;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3965;
import net.minecraft.class_5558;
import net.pneumono.gravestones.content.GravestonesRegistry;
import net.pneumono.gravestones.gravestones.GravestoneCollection;
import org.jetbrains.annotations.Nullable;

import java.util.Random;
import java.util.function.BiConsumer;

//? if <1.21.5 {
import net.pneumono.gravestones.api.GravestonesApi;
//?}

//? if <1.20.6 {
/*import net.minecraft.util.Hand;
*///?}

public class TechnicalGravestoneBlock extends AbstractGravestoneBlock {
    public static final class_2758 DAMAGE = class_2758.method_11867("damage", 0, 2);

    public TechnicalGravestoneBlock(class_2251 settings) {
        super(settings);
    }

    //? if >=1.20.4 {
    public static final MapCodec<TechnicalGravestoneBlock> field_46280 = TechnicalGravestoneBlock.method_54094(TechnicalGravestoneBlock::new);

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }
    //?}

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(DAMAGE);
    }

    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player,/*? <1.20.6 {*//*Hand hand,*//*?}*/ class_3965 hit) {
        if (!(world instanceof class_3218 serverWorld)) {
            return class_1269.field_5812;
        }

        createSoulParticles(world, pos);

        if (GravestoneCollection.collect(serverWorld, player, pos)) {
            player.method_7281(GravestonesRegistry.GRAVESTONES_COLLECTED);
        }

        return class_1269.field_5812;
    }

    //? if >=1.21.5 {
    /*@Override
    public void onStateReplaced(BlockState state, ServerWorld world, BlockPos pos, boolean moved) {
        ItemScatterer.onStateReplaced(state, world, pos);

        if (state.getBlock() != world.getBlockState(pos).getBlock()) {
            createSoulParticles(world, pos);
        }
    }
    *///?} else {
    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public void method_9536(class_2680 state, class_1937 world, class_2338 pos, class_2680 newState, boolean moved) {
        //? if >=1.20.4 {
        class_1264.method_54291(state, newState, world, pos);
        //?} else {
        /*world.updateComparators(pos, this);
        *///?}

        if (state.method_26204() != world.method_8320(pos).method_26204()) {
            createSoulParticles(world, pos);

            if (world instanceof class_3218 serverWorld && world.method_8321(pos) instanceof TechnicalGravestoneBlockEntity blockEntity) {
                GravestonesApi.onBreak(serverWorld, pos, state.method_11654(TechnicalGravestoneBlock.DAMAGE), blockEntity);
            }
        }

        super.method_9536(state, world, pos, newState, moved);
    }
    //?}

    public static void createSoulParticles(class_1937 world, class_2338 pos) {
        Random random = new Random();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            for (int i = 0; i < 16; ++i) {
                serverWorld.method_14199(class_2398.field_23114, pos.method_10263() + (random.nextFloat() * 0.6) + 0.2, pos.method_10264() + (random.nextFloat() / 10) + 0.25, pos.method_10260() + (random.nextFloat() * 0.6) + 0.2, 1, ((double) random.nextFloat() - 0.5) * 0.08, ((double) random.nextFloat() - 0.5) * 0.08, ((double) random.nextFloat() - 0.5) * 0.08, 0.1);
            }
        }
    }

    //? if >=1.20.4 {
    @Override
    public void method_55124(class_2680 state, /*? if >=1.21.3 {*//*ServerWorld*//*?} else {*/class_1937/*?}*/ world, class_2338 pos, class_1927 explosion, BiConsumer<class_1799, class_2338> stackMerger) {

    }
    //?}

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new TechnicalGravestoneBlockEntity(pos, state);
    }

    @Nullable
    @Override
    public <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return /*? if >=1.20.2 {*/method_31618/*?} else {*//*checkType*//*?}*/(type, GravestonesRegistry.TECHNICAL_GRAVESTONE_ENTITY, TechnicalGravestoneBlockEntity::tick);
    }
}

==> gravestones-1.2.6%2B1.21.4%2BA-sources.jar: net/pneumono/gravestones/block/TechnicalGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import com.mojang.serialization.MapCodec;
import net.minecraft.block.*;
import net.minecraft.class_1264;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1927;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2398;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import net.minecraft.class_3965;
import net.minecraft.class_5558;
import net.pneumono.gravestones.content.GravestonesRegistry;
import net.pneumono.gravestones.gravestones.GravestoneCollection;
import org.jetbrains.annotations.Nullable;

import java.util.Random;
import java.util.function.BiConsumer;

//? if <1.21.5 {
import net.pneumono.gravestones.api.GravestonesApi;
//?}

//? if <1.20.6 {
/*import net.minecraft.util.Hand;
*///?}

public class TechnicalGravestoneBlock extends AbstractGravestoneBlock {
    public static final class_2758 DAMAGE = class_2758.method_11867("damage", 0, 2);

    public TechnicalGravestoneBlock(class_2251 settings) {
        super(settings);
    }

    //? if >=1.20.4 {
    public static final MapCodec<TechnicalGravestoneBlock> field_46280 = TechnicalGravestoneBlock.method_54094(TechnicalGravestoneBlock::new);

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }
    //?}

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(DAMAGE);
    }

    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player,/*? <1.20.6 {*//*Hand hand,*//*?}*/ class_3965 hit) {
        if (!(world instanceof class_3218 serverWorld)) {
            return class_1269.field_5812;
        }

        createSoulParticles(world, pos);

        if (GravestoneCollection.collect(serverWorld, player, pos)) {
            player.method_7281(GravestonesRegistry.GRAVESTONES_COLLECTED);
        }

        return class_1269.field_5812;
    }

    //? if >=1.21.5 {
    /*@Override
    public void onStateReplaced(BlockState state, ServerWorld world, BlockPos pos, boolean moved) {
        ItemScatterer.onStateReplaced(state, world, pos);

        if (state.getBlock() != world.getBlockState(pos).getBlock()) {
            createSoulParticles(world, pos);
        }
    }
    *///?} else {
    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public void method_9536(class_2680 state, class_1937 world, class_2338 pos, class_2680 newState, boolean moved) {
        //? if >=1.20.4 {
        class_1264.method_54291(state, newState, world, pos);
        //?} else {
        /*world.updateComparators(pos, this);
        *///?}

        if (state.method_26204() != world.method_8320(pos).method_26204()) {
            createSoulParticles(world, pos);

            if (world instanceof class_3218 serverWorld && world.method_8321(pos) instanceof TechnicalGravestoneBlockEntity blockEntity) {
                GravestonesApi.onBreak(serverWorld, pos, state.method_11654(TechnicalGravestoneBlock.DAMAGE), blockEntity);
            }
        }

        super.method_9536(state, world, pos, newState, moved);
    }
    //?}

    public static void createSoulParticles(class_1937 world, class_2338 pos) {
        Random random = new Random();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            for (int i = 0; i < 16; ++i) {
                serverWorld.method_65096(class_2398.field_23114, pos.method_10263() + (random.nextFloat() * 0.6) + 0.2, pos.method_10264() + (random.nextFloat() / 10) + 0.25, pos.method_10260() + (random.nextFloat() * 0.6) + 0.2, 1, ((double) random.nextFloat() - 0.5) * 0.08, ((double) random.nextFloat() - 0.5) * 0.08, ((double) random.nextFloat() - 0.5) * 0.08, 0.1);
            }
        }
    }

    //? if >=1.20.4 {
    @Override
    public void method_55124(class_2680 state, /*? if >=1.21.3 {*/class_3218/*?} else {*//*World*//*?}*/ world, class_2338 pos, class_1927 explosion, BiConsumer<class_1799, class_2338> stackMerger) {

    }
    //?}

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new TechnicalGravestoneBlockEntity(pos, state);
    }

    @Nullable
    @Override
    public <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return /*? if >=1.20.2 {*/method_31618/*?} else {*//*checkType*//*?}*/(type, GravestonesRegistry.TECHNICAL_GRAVESTONE_ENTITY, TechnicalGravestoneBlockEntity::tick);
    }
}
